@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
-our $DATE = '2018-04-04'; # DATE
-our $VERSION = '0.340'; # VERSION
+our $DATE = '2019-01-17'; # DATE
+our $VERSION = '0.341'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,6 +22,7 @@ sub new {
     $attrs{default_section} //= 'GLOBAL';
     $attrs{allow_bang_only} //= 1;
     $attrs{allow_duplicate_key} //= 1;
+    $attrs{enable_directive} //= 1;
     $attrs{enable_encoding} //= 1;
     $attrs{enable_quoting}  //= 1;
     $attrs{enable_bracket}  //= 1;
@@ -350,7 +351,7 @@ sub _get_my_home_dir {
 }
 
 # borrowed from PERLANCAR::File::HomeDir 0.05, with some modifications
-sub _get_users_home_dir {
+sub _get_user_home_dir {
     my ($name) = @_;
 
     if ($^O eq 'MSWin32') {
@@ -398,7 +399,7 @@ sub _decode_path_or_paths {
 
     if ($val =~ m!\A~([^/]+)?(?:/|\z)!) {
         my $home_dir = length($1) ?
-            _get_users_home_dir($1) : _get_my_home_dir();
+            _get_user_home_dir($1) : _get_my_home_dir();
         unless ($home_dir) {
             if (length $1) {
                 return [500, "Can't get home directory for user '$1' in path"];
@@ -542,7 +543,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.340 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2018-04-04.
+This document describes version 0.341 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2019-01-17.
 
 =head1 EXPRESSION
 
@@ -611,6 +612,20 @@ C<Config::IOD::Expr::_Compiled> namespace, with C<no strict>, C<no warnings>.
 If a key line is specified before any section line, this is the section that the
 key will be put in.
 
+=head2 enable_directive => bool (default: 1)
+
+If set to false, then directives will not be parsed. Lines such as below will be
+considered a regular comment:
+
+ ;!include foo.ini
+
+and lines such as below will be considered a syntax error (B<regardless> of the
+C<allow_bang_only> setting):
+
+ !include foo.ini
+
+B<NOTE: Turning this setting off violates IOD specification.>
+
 =head2 enable_encoding => bool (default: 1)
 
 If set to false, then encoding notation will be ignored and key value will be
@@ -621,7 +636,7 @@ parsed as verbatim. Example:
 With C<enable_encoding> turned off, value will not be undef but will be string
 with the value of (as Perl literal) C<"!json null">.
 
-Turning off this setting will violate IOD.
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 enable_quoting => bool (default: 1)
 
@@ -633,7 +648,7 @@ parsed as verbatim. Example:
 With C<enable_quoting> turned off, value will not be a two-line string, but will
 be a one line string with the value of (as Perl literal) C<"line 1\\nline2">.
 
-I<Turning off this setting will violate IOD.>
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 enable_bracket => bool (default: 1)
 
@@ -644,7 +659,7 @@ If set to false, then JSON literal array will be parsed as verbatim. Example:
 With C<enable_bracket> turned off, value will not be a three-element array, but
 will be a string with the value of (as Perl literal) C<"[1,2,3]">.
 
-I<Turning off this setting will violate IOD.>
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 enable_brace => bool (default: 1)
 
@@ -656,7 +671,7 @@ Example:
 With C<enable_brace> turned off, value will not be a hash with two pairs, but
 will be a string with the value of (as Perl literal) C<'{"a":1,"b":2}'>.
 
-I<Turning off this setting will violate IOD.>
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 enable_tilde => bool (default: 1)
 
@@ -670,7 +685,7 @@ Example:
 
 With C<enable_tilde> turned off, value will still be literally C<~/logs>.
 
-I<Turning off this setting will violate IOD.>
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 allow_encodings => array
 
@@ -740,14 +755,14 @@ config file and force user to use JSON encoding or bracket to specify array:
  [section]
  a=[1,2]
 
-I<Turning off this setting will violate IOD.>
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 ignore_unknown_directive => bool (default: 0)
 
 If set to true, will not die if an unknown directive is encountered. It will
 simply be ignored as a regular comment.
 
-I<Turning on this setting will violate IOD.>
+B<NOTE: Turning this setting on violates IOD specification.>
 
 =for END_BLOCK: attributes
 
@@ -787,7 +802,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
