@@ -1,7 +1,7 @@
 package Config::IOD::Reader;
 
-our $DATE = '2018-04-04'; # DATE
-our $VERSION = '0.340'; # VERSION
+our $DATE = '2019-01-17'; # DATE
+our $VERSION = '0.341'; # VERSION
 
 use 5.010001;
 use strict;
@@ -67,7 +67,7 @@ sub _read_string {
         }
 
         # directive line
-        if ($line =~ s/$directive_re//) {
+        if ($self->{enable_directive} && $line =~ s/$directive_re//) {
             my $directive = $1;
             if ($self->{allow_directives}) {
                 $self->_err("Directive '$directive' is not in ".
@@ -230,7 +230,7 @@ Config::IOD::Reader - Read IOD/INI configuration files
 
 =head1 VERSION
 
-This document describes version 0.340 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2018-04-04.
+This document describes version 0.341 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2019-01-17.
 
 =head1 SYNOPSIS
 
@@ -322,6 +322,20 @@ C<Config::IOD::Expr::_Compiled> namespace, with C<no strict>, C<no warnings>.
 If a key line is specified before any section line, this is the section that the
 key will be put in.
 
+=head2 enable_directive => bool (default: 1)
+
+If set to false, then directives will not be parsed. Lines such as below will be
+considered a regular comment:
+
+ ;!include foo.ini
+
+and lines such as below will be considered a syntax error (B<regardless> of the
+C<allow_bang_only> setting):
+
+ !include foo.ini
+
+B<NOTE: Turning this setting off violates IOD specification.>
+
 =head2 enable_encoding => bool (default: 1)
 
 If set to false, then encoding notation will be ignored and key value will be
@@ -332,7 +346,7 @@ parsed as verbatim. Example:
 With C<enable_encoding> turned off, value will not be undef but will be string
 with the value of (as Perl literal) C<"!json null">.
 
-Turning off this setting will violate IOD.
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 enable_quoting => bool (default: 1)
 
@@ -344,7 +358,7 @@ parsed as verbatim. Example:
 With C<enable_quoting> turned off, value will not be a two-line string, but will
 be a one line string with the value of (as Perl literal) C<"line 1\\nline2">.
 
-I<Turning off this setting will violate IOD.>
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 enable_bracket => bool (default: 1)
 
@@ -355,7 +369,7 @@ If set to false, then JSON literal array will be parsed as verbatim. Example:
 With C<enable_bracket> turned off, value will not be a three-element array, but
 will be a string with the value of (as Perl literal) C<"[1,2,3]">.
 
-I<Turning off this setting will violate IOD.>
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 enable_brace => bool (default: 1)
 
@@ -367,7 +381,7 @@ Example:
 With C<enable_brace> turned off, value will not be a hash with two pairs, but
 will be a string with the value of (as Perl literal) C<'{"a":1,"b":2}'>.
 
-I<Turning off this setting will violate IOD.>
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 enable_tilde => bool (default: 1)
 
@@ -381,7 +395,7 @@ Example:
 
 With C<enable_tilde> turned off, value will still be literally C<~/logs>.
 
-I<Turning off this setting will violate IOD.>
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 allow_encodings => array
 
@@ -451,14 +465,14 @@ config file and force user to use JSON encoding or bracket to specify array:
  [section]
  a=[1,2]
 
-I<Turning off this setting will violate IOD.>
+B<NOTE: Turning this setting off violates IOD specification.>
 
 =head2 ignore_unknown_directive => bool (default: 0)
 
 If set to true, will not die if an unknown directive is encountered. It will
 simply be ignored as a regular comment.
 
-I<Turning on this setting will violate IOD.>
+B<NOTE: Turning this setting on violates IOD specification.>
 
 =head1 METHODS
 
@@ -536,7 +550,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
