@@ -1,7 +1,7 @@
 package Test::Config::IOD::Common;
 
-our $DATE = '2018-04-04'; # DATE
-our $VERSION = '0.340'; # VERSION
+our $DATE = '2019-01-17'; # DATE
+our $VERSION = '0.341'; # VERSION
 
 use 5.010;
 use strict;
@@ -72,6 +72,31 @@ _
         );
     };
 
+    subtest "opt: enable_directive=0" => sub {
+        test_read_iod(
+            args  => {enable_directive=>0},
+            input => <<'_',
+[s1]
+a=1
+[s2]
+;!merge s1
+b=2
+_
+            result => {s1=>{a=>1}, s2=>{b=>2}},
+        );
+        test_read_iod(
+            args  => {enable_directive=>0},
+            input => <<'_',
+[s1]
+a=1
+[s2]
+!merge s1
+b=2
+_
+            dies => 1,
+        );
+    };
+
     subtest "opt: enable_quoting=0" => sub {
         test_read_iod(
             args  => {enable_quoting=>0},
@@ -279,7 +304,7 @@ Test::Config::IOD::Common - Common tests for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.340 of Test::Config::IOD::Common (from Perl distribution Config-IOD-Reader), released on 2018-04-04.
+This document describes version 0.341 of Test::Config::IOD::Common (from Perl distribution Config-IOD-Reader), released on 2019-01-17.
 
 =for Pod::Coverage .+
 
@@ -305,7 +330,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
